@@ -1,21 +1,9 @@
 /*******************************************************************
  KNotes -- Notes for the KDE project
 
- Copyright (c) 1997-2013, The KNotes Developers
+ SPDX-FileCopyrightText: 1997-2013 The KNotes Developers
 
- This program is free software; you can redistribute it and/or
- modify it under the terms of the GNU General Public License
- as published by the Free Software Foundation; either version 2
- of the License, or (at your option) any later version.
-
- This program is distributed in the hope that it will be useful,
- but WITHOUT ANY WARRANTY; without even the implied warranty of
- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- GNU General Public License for more details.
-
- You should have received a copy of the GNU General Public License
- along with this program; if not, write to the Free Software
- Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ SPDX-License-Identifier: GPL-2.0-or-later
 *******************************************************************/
 
 #include "knoteedit.h"
@@ -97,7 +85,7 @@ KNoteEdit::KNoteEdit(KActionCollection *actions, QWidget *parent)
     connect(m_textAlignBlock, &KToggleAction::triggered, this, &KNoteEdit::textAlignBlock);
     actions->setDefaultShortcut(m_textAlignBlock, QKeySequence(Qt::ALT + Qt::Key_B));
 
-    QActionGroup *group = new QActionGroup(this);
+    auto *group = new QActionGroup(this);
     group->addAction(m_textAlignLeft);
     group->addAction(m_textAlignCenter);
     group->addAction(m_textAlignRight);
