@@ -1,26 +1,10 @@
 /*
   This file is part of Kontact.
 
-  Copyright (c) 2003 Tobias Koenig <tokoe@kde.org>
-  Copyright (C) 2014-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2003 Tobias Koenig <tokoe@kde.org>
+  SPDX-FileCopyrightText: 2014-2020 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-
-  As a special exception, permission is given to link this program
-  with any edition of Qt, and distribute the resulting executable,
-  without including the source code for Qt in the source distribution.
+  SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
 #include "summarywidget.h"
@@ -55,7 +39,7 @@ KNotesSummaryWidget::KNotesSummaryWidget(KontactInterface::Plugin *plugin, QWidg
     , mInProgress(false)
 {
     mDefaultPixmap = KIconLoader::global()->loadIcon(QStringLiteral("knotes"), KIconLoader::Desktop);
-    QVBoxLayout *mainLayout = new QVBoxLayout(this);
+    auto *mainLayout = new QVBoxLayout(this);
     mainLayout->setSpacing(3);
     mainLayout->setContentsMargins(3, 3, 3, 3);
 
@@ -189,12 +173,14 @@ void KNotesSummaryWidget::createNote(const Akonadi::Item &item, int counter)
     urlLabel->setAlignment(Qt::AlignLeft);
     urlLabel->setWordWrap(true);
     connect(urlLabel, &KUrlLabel::leftClickedUrl, this, [this, urlLabel]() {
-        slotSelectNote(urlLabel->url()); }
-    );
+        slotSelectNote(urlLabel->url());
+    }
+            );
 
     connect(urlLabel, &KUrlLabel::rightClickedUrl, this, [this, urlLabel]() {
-        slotPopupMenu(urlLabel->url()); }
-    );
+        slotPopupMenu(urlLabel->url());
+    }
+            );
     mLayout->addWidget(urlLabel, counter, 1);
 
     QColor color;
@@ -238,7 +224,7 @@ void KNotesSummaryWidget::slotSelectNote(const QString &note)
 bool KNotesSummaryWidget::eventFilter(QObject *obj, QEvent *e)
 {
     if (obj->inherits("KUrlLabel")) {
-        KUrlLabel *label = static_cast<KUrlLabel *>(obj);
+        auto *label = static_cast<KUrlLabel *>(obj);
         if (e->type() == QEvent::Enter) {
             Q_EMIT message(i18n("Read Popup Note: \"%1\"", label->text()));
         } else if (e->type() == QEvent::Leave) {
